@@ -93,7 +93,8 @@ class CubeQuery:
     def possible_materialized_views(
         self,
     ) -> [Type["AggregatingMaterializedView"]]:  # noqa - circular import
-        if not self.cube._materialized_views:
+        mat_views = [mv for mv in self.cube._materialized_views if not mv.projection]
+        if not mat_views:
             return []
         # we only support Sum and Count aggregations in materialized views at present, so any other
         # aggregation makes use of materialized views impossible
