@@ -344,10 +344,7 @@ class ClickhouseCubeBackend(CubeBackend):
         return text, params, fields, matview
 
     def _get_query_settings(self) -> dict:
-        out = {**self.default_settings, **self.query_settings}
-        if not GlobalSettings.aggregates_zero_for_empty_data:
-            out["aggregate_functions_null_for_empty"] = 1
-        return out
+        return {**self.default_settings, **self.query_settings}
 
     def _translate_aggregation(self, agg: Aggregation, sign_column: Optional[str]) -> str:
         agg_name = self._agg_name(agg.op)
@@ -389,6 +386,10 @@ class ClickhouseCubeBackend(CubeBackend):
 
     def _agg_name(self, agg: AggregationOp):
         if agg in (AggregationOp.SUM, AggregationOp.COUNT, AggregationOp.MAX, AggregationOp.MIN):
+            # CH aggregations return 0 by default, but we want None to be compatible with other
+            # backends, most notably standard SQL
+            if not GlobalSettings.aggregates_zero_for_empty_data and agg != AggregationOp.COUNT:
+                return f"{agg.name}OrNull"
             return agg.name
         raise ValueError(f"Unsupported aggregation {agg}")
 
@@ -499,11 +500,11 @@ class ClickhouseCubeBackend(CubeBackend):
     def _create_projection(
         self, cube: Type[Cube], matview: Type[AggregatingMaterializedView], populate=True
     ):
+        meta = self.get_table_meta(cube)
         preserved = ", ".join(dim.name for dim in matview._dimensions.values())
-        aggregs = [
-            f"{self._agg_name(agg.op)}({agg.metric.name}) AS {agg.metric.name}"
-            for agg in matview._aggregations
-        ]
+        aggregs = [self._translate_aggregation(agg, meta.sign_col) for agg in matview._aggregations]
+        if matview.preserve_sign:
+            aggregs.append(f"SUM({meta.sign_col}) AS _{meta.sign_col}")
         agg_part = ", ".join(aggregs)
         table_name = self.cube_to_table_name(cube)
         view_name = self.cube_to_table_name(matview)
